@@ -10,11 +10,10 @@
 # ---------------------------------------------------------------------------------------------------------
 """
 import asyncio
-from typing import Optional
 from playwright.async_api import BrowserContext, Page
 
 
-async def switch_for_table_window(browser: BrowserContext, url_keyword: str, wait_time: int = 10) -> Optional[Page]:
+async def switch_for_table_window(browser: BrowserContext, url_keyword: str, wait_time: float = 10.0) -> Page:
     # 最多等待 wait_time 秒
     for _ in range(int(wait_time) * 10):
         await asyncio.sleep(delay=0.1)
@@ -22,4 +21,4 @@ async def switch_for_table_window(browser: BrowserContext, url_keyword: str, wai
             if url_keyword.lower() in page.url.lower():
                 await page.bring_to_front()
                 return page
-    return None
\ No newline at end of file
+    raise RuntimeError(f"根据关键信息<{url_keyword}>，没有找到浏览器的page对象")
\ No newline at end of file
